@@ -12,7 +12,7 @@ import tempfile
 import unittest
 from array import array
 from string import hexdigits
-from random import choice, randint, random
+from random import choice, getrandbits, randrange, randint, random
 from collections import Counter
 
 from bitarray import (bitarray, frozenbitarray, decodetree, bits2bytes,
@@ -20,7 +20,7 @@ from bitarray import (bitarray, frozenbitarray, decodetree, bits2bytes,
 from bitarray.test_bitarray import Util, skipIf, SYSINFO, DEBUG
 
 from bitarray.util import (
-    zeros, urandom, pprint, make_endian, rindex, strip, count_n,
+    zeros, ones, urandom, pprint, make_endian, rindex, strip, count_n,
     parity, count_and, count_or, count_xor, any_and, subset, _correspond_all,
     intervals,
     serialize, deserialize, ba2hex, hex2ba, ba2base, base2ba,
@@ -31,56 +31,62 @@ from bitarray.util import (
 
 if DEBUG:
     from bitarray._util import _sc_rts, _SEGSIZE  # type: ignore
-else:
-    _SEGSIZE = -1
 
 if sys.version_info[0] == 3:
     from io import StringIO
 else:
     from io import BytesIO as StringIO
 
-tests = []  # type: list
-
 # ---------------------------------------------------------------------------
 
-class TestsZeros(unittest.TestCase):
+class TestsZerosOnes(unittest.TestCase):
 
-    def test_basic(self):
+    def test_range(self):
+        for n in range(100):
+            a = zeros(n)
+            self.assertEqual(len(a), n)
+            self.assertFalse(a.any())
+            self.assertEqual(a.count(0), n)
+            self.assertEqual(a.count(1), 0)
+            self.assertIsInstance(a, bitarray)
+            b = ones(n)
+            self.assertEqual(len(b), n)
+            self.assertTrue(b.all())
+            self.assertEqual(b.count(0), 0)
+            self.assertEqual(b.count(1), n)
+            self.assertIsInstance(b, bitarray)
+
+    def test_endian(self):
         for default_endian in 'big', 'little':
             _set_default_endian(default_endian)
 
-            for a in zeros(0), zeros(0, None), zeros(0, endian=None):
+            for a in (zeros(0), zeros(0, None), zeros(0, endian=None),
+                      ones(0), ones(0, None), ones(0, endian=None)):
                 self.assertEqual(a, bitarray())
                 self.assertEqual(a.endian(), default_endian)
 
-            for n in range(100):
-                a = zeros(n)
-                self.assertEqual(len(a), n)
-                self.assertFalse(a.any())
-                self.assertEqual(a.count(1), 0)
-                self.assertEqual(a, bitarray(n * '0'))
-                self.assertIsInstance(a, bitarray)
-
             for endian in 'big', 'little':
                 for a in zeros(3, endian), zeros(3, endian=endian):
                     self.assertEqual(a, bitarray('000'))
                     self.assertEqual(a.endian(), endian)
+                for b in ones(3, endian), ones(3, endian=endian):
+                    self.assertEqual(b, bitarray('111'))
+                    self.assertEqual(b.endian(), endian)
 
     def test_wrong_args(self):
-        self.assertRaises(TypeError, zeros) # no argument
-        self.assertRaises(TypeError, zeros, '')
-        self.assertRaises(TypeError, zeros, bitarray())
-        self.assertRaises(TypeError, zeros, [])
-        self.assertRaises(TypeError, zeros, 1.0)
-        self.assertRaises(ValueError, zeros, -1)
+        for f in zeros, ones:
+            self.assertRaises(TypeError, f) # no argument
+            self.assertRaises(TypeError, f, '')
+            self.assertRaises(TypeError, f, bitarray())
+            self.assertRaises(TypeError, f, [])
+            self.assertRaises(TypeError, f, 1.0)
+            self.assertRaises(ValueError, f, -1)
 
-        # endian not string
-        for x in 0, 1, {}, [], False, True:
-            self.assertRaises(TypeError, zeros, 0, x)
-        # endian wrong string
-        self.assertRaises(ValueError, zeros, 0, 'foo')
-
-tests.append(TestsZeros)
+            # endian not string
+            for x in 0, 1, {}, [], False, True:
+                self.assertRaises(TypeError, f, 0, x)
+            # endian wrong string
+            self.assertRaises(ValueError, f, 0, 'foo')
 
 # ---------------------------------------------------------------------------
 
@@ -122,8 +128,6 @@ class TestsURandom(unittest.TestCase):
         self.assertRaises(TypeError, urandom, 0, 1)
         self.assertRaises(ValueError, urandom, 0, 'foo')
 
-tests.append(TestsURandom)
-
 # ---------------------------------------------------------------------------
 
 class TestsPPrint(unittest.TestCase):
@@ -195,8 +199,6 @@ class TestsPPrint(unittest.TestCase):
         finally:
             shutil.rmtree(tmpdir)
 
-tests.append(TestsPPrint)
-
 # ---------------------------------------------------------------------------
 
 class TestsMakeEndian(unittest.TestCase, Util):
@@ -242,8 +244,6 @@ class TestsMakeEndian(unittest.TestCase, Util):
                     self.assertTrue(b is a)
             self.assertEQUAL(a, aa)
 
-tests.append(TestsMakeEndian)
-
 # ---------------------------------------------------------------------------
 
 class TestsRIndex(unittest.TestCase, Util):
@@ -288,7 +288,7 @@ class TestsRIndex(unittest.TestCase, Util):
                               bitarray('11111', endian), 0)
 
     def test_range(self):
-        n = 250
+        n = 100
         a = bitarray(n)
         for m in range(n):
             a.setall(0)
@@ -303,7 +303,7 @@ class TestsRIndex(unittest.TestCase, Util):
 
     def test_random(self):
         for a in self.randombitarrays():
-            v = randint(0, 1)
+            v = getrandbits(1)
             try:
                 i = rindex(a, v)
             except ValueError:
@@ -316,12 +316,11 @@ class TestsRIndex(unittest.TestCase, Util):
             self.assertEqual(i, j)
 
     def test_random_start_stop(self):
-        n = 2000
-        a = zeros(n)
-        indices = [randint(0, n - 1) for _ in range(100)]
-        for i in indices:
-            a[i] = 1
-        for _ in range(100):
+        for _ in range(10):
+            n = randrange(1, 1000)
+            a = zeros(n)
+            indices = [randrange(n) for _ in range(100)]
+            a[indices] = 1
             start = randint(0, n)
             stop = randint(0, n)
             filtered = [i for i in indices if i >= start and i < stop]
@@ -335,24 +334,20 @@ class TestsRIndex(unittest.TestCase, Util):
     def test_many_set(self):
         for _ in range(10):
             n = randint(1, 10000)
-            v = randint(0, 1)
+            v = getrandbits(1)
             a = bitarray(n)
             a.setall(not v)
-            lst = [randint(0, n - 1) for _ in range(100)]
-            for i in lst:
-                a[i] = v
+            lst = [randrange(n) for _ in range(100)]
+            a[lst] = v
             self.assertEqual(rindex(a, v), max(lst))
 
     def test_one_set(self):
         for _ in range(10):
             N = randint(1, 10000)
-            a = bitarray(N)
-            a.setall(0)
-            a[randint(0, N - 1)] = 1
+            a = zeros(N)
+            a[randrange(N)] = 1
             self.assertEqual(rindex(a), a.index(1))
 
-tests.append(TestsRIndex)
-
 # ---------------------------------------------------------------------------
 
 class TestsStrip(unittest.TestCase, Util):
@@ -372,7 +367,7 @@ class TestsStrip(unittest.TestCase, Util):
             self.assertEqual(c, bitarray('1011'))
             self.assertIsType(c, 'frozenbitarray')
 
-    def test_zeros(self):
+    def test_zeros_ones(self):
         for n in range(10):
             for mode in 'left', 'right', 'both':
                 a = zeros(n)
@@ -386,6 +381,10 @@ class TestsStrip(unittest.TestCase, Util):
                 self.assertIsType(c, 'frozenbitarray')
                 self.assertEqual(c, bitarray())
 
+                a.setall(1)
+                c = strip(a, mode)
+                self.assertEqual(c, ones(n))
+
     def test_random(self):
         for a in self.randombitarrays():
             b = a.copy()
@@ -411,12 +410,10 @@ class TestsStrip(unittest.TestCase, Util):
             n = randint(1, 10000)
             a = bitarray(n)
             a.setall(0)
-            a[randint(0, n - 1)] = 1
+            a[randrange(n)] = 1
             self.assertEqual(strip(a, 'both'), bitarray('1'))
             self.assertEqual(len(a), n)
 
-tests.append(TestsStrip)
-
 # ---------------------------------------------------------------------------
 
 class TestsCount_N(unittest.TestCase, Util):
@@ -507,8 +504,7 @@ class TestsCount_N(unittest.TestCase, Util):
 
     def test_ones(self):
         n = randint(1, 100000)
-        a = bitarray(n)
-        a.setall(1)
+        a = ones(n)
         self.assertEqual(count_n(a, n), n)
         self.assertRaises(ValueError, count_n, a, 1, 0)
         self.assertRaises(ValueError, count_n, a, n + 1)
@@ -518,13 +514,12 @@ class TestsCount_N(unittest.TestCase, Util):
 
     def test_one_set(self):
         n = randint(1, 100000)
-        a = bitarray(n)
-        a.setall(0)
+        a = zeros(n)
         self.assertEqual(count_n(a, 0), 0)
         self.assertRaises(ValueError, count_n, a, 1)
         for _ in range(20):
             a.setall(0)
-            i = randint(0, n - 1)
+            i = randrange(n)
             a[i] = 1
             self.assertEqual(count_n(a, 1), i + 1)
             self.assertRaises(ValueError, count_n, a, 2)
@@ -545,16 +540,17 @@ class TestsCount_N(unittest.TestCase, Util):
         for _ in range(100):
             N = randint(100000, 250000)
             a = bitarray(N)
-            v = randint(0, 1)
+            v = getrandbits(1)
             a.setall(not v)
-            for _ in range(randint(0, 100)):
-                a[randint(0, N - 1)] = v
+            for _ in range(randrange(100)):
+                a[randrange(N)] = v
             tc = a.count(v)      # total count
             i = count_n(a, tc, v)
             self.check_result(a, tc, i, v)
+            n = tc + 1
             self.assertRaisesMessage(ValueError, "n = %d exceeds total count "
-                                     "(a.count(%d) = %d)" % (tc + 1, v, tc),
-                                     count_n, a, tc + 1, v)
+                                     "(a.count(%d) = %d)" % (n, v, tc),
+                                     count_n, a, n, v)
             for _ in range(20):
                 n = randint(0, tc)
                 i = count_n(a, n, v)
@@ -566,30 +562,26 @@ class TestsCount_N(unittest.TestCase, Util):
                 n = a.count(v) // 2
                 i = count_n(a, n, v)
                 self.check_result(a, n, i, v)
-
-tests.append(TestsCount_N)
+                # n = 0 -> count_n always 0
+                self.assertEqual(count_n(a, 0, v), 0)
 
 # ---------------------------------------------------------------------------
 
 class TestsBitwiseCount(unittest.TestCase, Util):
 
     def test_count_byte(self):
-        ones = bitarray(8)
-        ones.setall(1)
-        zeros = bitarray(8)
-        zeros.setall(0)
         for i in range(256):
             a = bitarray()
             a.frombytes(bytes(bytearray([i])))
             cnt = a.count()
-            self.assertEqual(count_and(a, zeros), 0)
-            self.assertEqual(count_and(a, ones), cnt)
+            self.assertEqual(count_and(a, zeros(8)), 0)
+            self.assertEqual(count_and(a, ones(8)), cnt)
             self.assertEqual(count_and(a, a), cnt)
-            self.assertEqual(count_or(a, zeros), cnt)
-            self.assertEqual(count_or(a, ones), 8)
+            self.assertEqual(count_or(a, zeros(8)), cnt)
+            self.assertEqual(count_or(a, ones(8)), 8)
             self.assertEqual(count_or(a, a), cnt)
-            self.assertEqual(count_xor(a, zeros), cnt)
-            self.assertEqual(count_xor(a, ones), 8 - cnt)
+            self.assertEqual(count_xor(a, zeros(8)), cnt)
+            self.assertEqual(count_xor(a, ones(8)), 8 - cnt)
             self.assertEqual(count_xor(a, a), 0)
 
     def test_1(self):
@@ -628,7 +620,7 @@ class TestsBitwiseCount(unittest.TestCase, Util):
 
     def test_random(self):
         for _ in range(100):
-            n = randint(0, 1000)
+            n = randrange(1000)
             a = urandom(n, self.random_endian())
             b = urandom(n, a.endian())
             self.assertEqual(count_and(a, b), (a & b).count())
@@ -658,8 +650,6 @@ class TestsBitwiseCount(unittest.TestCase, Util):
             self.assertEqual(all(a ^ b), count_xor(a, b) == n)
             self.assertEqual(all(a ^ b), a == ~b)
 
-tests.append(TestsBitwiseCount)
-
 # ---------------------------------------------------------------------------
 
 class TestsBitwiseAny(unittest.TestCase, Util):
@@ -707,12 +697,10 @@ class TestsBitwiseAny(unittest.TestCase, Util):
         for n in range(1, 300):
             a = zeros(n)
             b = urandom(n)
-            i = randint(0, n - 1)
+            i = randrange(n)
             a[i] = 1
             self.assertEqual(b[i], any_and(a, b))
 
-tests.append(TestsBitwiseAny)
-
 # ---------------------------------------------------------------------------
 
 class TestsSubset(unittest.TestCase, Util):
@@ -754,7 +742,7 @@ class TestsSubset(unittest.TestCase, Util):
         for a in self.randombitarrays(start=1):
             b = a.copy()
             # we set one random bit in b to 1, so a is always a subset of b
-            b[randint(0, len(a) - 1)] == 1
+            b[randrange(len(a))] == 1
             self.check(a, b, True)
             # but b is only a subset when they are equal
             self.check(b, a, a == b)
@@ -762,8 +750,6 @@ class TestsSubset(unittest.TestCase, Util):
             a.setall(1)
             self.check(b, a, True)
 
-tests.append(TestsSubset)
-
 # ---------------------------------------------------------------------------
 
 class TestsCorrespondAll(unittest.TestCase, Util):
@@ -801,8 +787,6 @@ class TestsCorrespondAll(unittest.TestCase, Util):
             self.assertEqual(res[1] + res[2], count_xor(a, b))
             self.assertEqual(sum(res), n)
 
-tests.append(TestsCorrespondAll)
-
 # ---------------------------------------------------------------------------
 
 class TestsParity(unittest.TestCase, Util):
@@ -817,8 +801,7 @@ class TestsParity(unittest.TestCase, Util):
             par = not par
 
     def test_pad_ignored(self):
-        a = bitarray(1)
-        a.setall(1)
+        a = ones(1)
         self.assertTrue(parity(a))
 
     def test_frozenbitarray(self):
@@ -841,8 +824,6 @@ class TestsParity(unittest.TestCase, Util):
             self.assertEqual(parity(a), a.count() % 2)
             self.assertEqual(a, b)
 
-tests.append(TestsParity)
-
 # ---------------------------------------------------------------------------
 
 class TestsIntervals(unittest.TestCase, Util):
@@ -903,8 +884,6 @@ class TestsIntervals(unittest.TestCase, Util):
 
             self.assertEqual(a, b)
 
-tests.append(TestsIntervals)
-
 # ---------------------------------------------------------------------------
 
 class TestsHexlify(unittest.TestCase, Util):
@@ -955,10 +934,18 @@ class TestsHexlify(unittest.TestCase, Util):
         for endian in 'little', 'big':
             _set_default_endian(endian)
             self.assertRaises(ValueError, hex2ba, '01a7g89')
-            self.assertRaises(UnicodeEncodeError, hex2ba, u'10\u20ac')
+            self.assertRaises(ValueError, hex2ba, u'0\u20ac')
+
+            for s in 'g', 'ag', 'aag' 'aaaga', 'ag':
+                msg = "non-hexadecimal digit found, got 'g' (0x67)"
+                self.assertRaisesMessage(ValueError, msg, hex2ba, s, endian)
+
             # check for NUL bytes
             for b in b'\0', b'\0f', b'f\0', b'\0ff', b'f\0f', b'ff\0':
-                self.assertRaises(ValueError, hex2ba, b)
+                msg = "non-hexadecimal digit found, got '\0' (0x00)"
+                if sys.version_info[0] == 2:
+                    msg = msg.replace("0x00", "0x0")
+                self.assertRaisesMessage(ValueError, msg, hex2ba, b, endian)
 
     def test_explicit(self):
         data = [ #                       little   big
@@ -999,8 +986,6 @@ class TestsHexlify(unittest.TestCase, Util):
         b.frombytes(binascii.unhexlify(s))
         self.assertEQUAL(hex2ba(s, 'big'), b)
 
-tests.append(TestsHexlify)
-
 # ---------------------------------------------------------------------------
 
 class TestsBase(unittest.TestCase, Util):
@@ -1047,7 +1032,12 @@ class TestsBase(unittest.TestCase, Util):
     def test_invalid_characters(self):
         for n, s in ((2, '2'), (4, '4'), (8, '8'), (16, 'g'), (32, '8'),
                      (32, '1'), (32, 'a'), (64, '-'), (64, '_')):
-            self.assertRaises(ValueError, base2ba, n, s)
+            if n == 16:
+                msg = "non-hexadecimal digit found, got 'g' (0x67)"
+            else:
+                msg = ("invalid digit found for base %d, "
+                       "got '%s' (0x%02x)" % (n, s, ord(s)))
+            self.assertRaisesMessage(ValueError, msg, base2ba, n, s)
 
     def test_invalid_args(self):
         a = bitarray()
@@ -1065,7 +1055,8 @@ class TestsBase(unittest.TestCase, Util):
         self.assertRaises(TypeError, base2ba, 32, None)
 
         for i in 2, 4, 8, 16, 32, 64:
-            self.assertRaises(UnicodeEncodeError, base2ba, i, u'10\u20ac')
+            self.assertRaises(ValueError, base2ba, i, 60 * u'\u20ac')
+            self.assertRaises(ValueError, base2ba, i, 60 * b'\0')
 
     def test_binary(self):
         a = base2ba(2, '1011')
@@ -1155,12 +1146,12 @@ class TestsBase(unittest.TestCase, Util):
             n = 1 << m
             for length in range(0, 100, m):
                 a = urandom(length, 'little')
-                self.assertEQUAL(base2ba(n, ba2base(n, a), 'little'), a)
+                s = ba2base(n, a)
+                self.assertIsInstance(s, str)
+                self.assertEQUAL(base2ba(n, s, 'little'), a)
                 b = bitarray(a, 'big')
                 self.assertEQUAL(base2ba(n, ba2base(n, b), 'big'), b)
 
-tests.append(TestsBase)
-
 # ---------------------------------------------------------------------------
 
 class SC_Tests(unittest.TestCase, Util):
@@ -1213,7 +1204,7 @@ class SC_Tests(unittest.TestCase, Util):
                                      sc_decode,
                                      bytearray([c]))
         # invalid block head
-        for c in 0x81, 0x9f, 0xc0, 0xc1, 0xc5, 0xff:
+        for c in 0xc0, 0xc1, 0xc5, 0xff:
             self.assertRaisesMessage(ValueError,
                                      "invalid block head: 0x%02x" % c,
                                      sc_decode,
@@ -1312,24 +1303,6 @@ class SC_Tests(unittest.TestCase, Util):
             a = sc_decode(b)
             self.assertEqual(a.to01(), '001')
 
-    @skipIf(sys.version_info[0] == 2)
-    def test_raw_block(self):
-        a = bitarray(0, 'big')
-        for nbytes in range(1, 129):
-            nbits = 8 * nbytes
-            raw = nbytes * b'\xf7'
-            if nbits < 256:
-                b = bytearray([0x11, nbits])
-            else:
-                b = bytearray([0x12, nbits & 0xff, nbits >> 8])
-            b.append(nbytes)  # head byte
-            b.extend(raw)
-            b.append(0)       # stop byte
-
-            a.frombytes(b'\xf7')
-            self.assertEqual(sc_decode(b), a)
-            self.assertEqual(sc_encode(a), bytes(b))
-
     @skipIf(sys.version_info[0] == 2)
     def test_sparse_block_type1(self):
         a = bitarray(256, 'little')
@@ -1340,8 +1313,7 @@ class SC_Tests(unittest.TestCase, Util):
             b.append(0)  # stop byte
 
             a.setall(0)
-            for p in positions:
-                a[p] = 1
+            a[positions] = 1
             self.assertEqual(sc_decode(b), a)
 
             # in order to recreate the block sc_encode generates, we need
@@ -1356,9 +1328,8 @@ class SC_Tests(unittest.TestCase, Util):
 
     def test_decode_random_bytes(self):
         # ensure random input doesn't crash the decoder
-        cnt = 0
-        for _ in range(5000):
-            n = randint(0, 20)
+        for _ in range(100):
+            n = randrange(20)
             b = b'\x02\x00\x04' + os.urandom(n)
             try:
                 a = sc_decode(b)
@@ -1367,8 +1338,6 @@ class SC_Tests(unittest.TestCase, Util):
                     continue
             self.assertEqual(len(a), 1024)
             self.assertEqual(a.endian(), 'little')
-            cnt += 1
-        self.assertTrue(cnt > 2)
 
     def test_encode_types(self):
         for a in bitarray('1', 'big'), frozenbitarray('1', 'big'):
@@ -1381,22 +1350,28 @@ class SC_Tests(unittest.TestCase, Util):
 
     def round_trip(self, a):
         c = a.copy()
-        b = sc_decode(sc_encode(a))
+        i = iter(sc_encode(a))
+        b = sc_decode(i)
         self.assertTrue(a == b == c)
         self.assertTrue(a.endian() == b.endian() == c.endian())
+        if sys.version_info[0] == 3:
+            self.assertEqual(bytes(i), b'')
 
     def test_encode_zeros(self):
         for i in range(18):
             n = 1 << i
-            a = bitarray(n)
-            a.setall(0)
+            a = zeros(n)
             m = 2                            # head byte and stop byte
             m += bits2bytes(n.bit_length())  # size bytes
-            # For smaller or equal to 1 << 32, we have only one type 4 block.
-            m += bool(n > 0)                 # number of blocks (head bytes)
-            m += bool(n > 256)               # number of second block heads
-            b = sc_encode(a)
-            self.assertEqual(m, len(b))
+            #print(i, n, m, sc_encode(a))
+            self.assertEqual(m, len(sc_encode(a)))
+            self.round_trip(a)
+
+            a[0] = 1
+            m += 2                  # block head byte and one index byte
+            m += 2 * bool(n > 512)  # second block head and second index byte
+            m += bool(n > 65536)    # third index byte
+            self.assertEqual(m, len(sc_encode(a)))
             self.round_trip(a)
 
         a = zeros(1 << 25, 'big')
@@ -1407,32 +1382,33 @@ class SC_Tests(unittest.TestCase, Util):
 
     def test_encode_ones(self):
         for _ in range(50):
-            n = randint(0, 10000)
-            a = bitarray(n)
-            a.setall(1)
-            m = 2                            # head byte and stop byte
-            m += bits2bytes(n.bit_length())  # size bytes
-            m += (n + 1023) // 1024          # number of blocks (head bytes)
-            m += bits2bytes(n)               # actual raw bytes
+            nbits = randrange(100000)
+            a = ones(nbits)
+            m = 2                                # head byte and stop byte
+            m += bits2bytes(nbits.bit_length())  # size bytes
+            nbytes = bits2bytes(nbits)
+            m += (nbytes // 32 + 127) // 128  # number of blocks (head bytes)
+            m += bool(nbytes % 32)            # block type 0 range(1, 32)
+            m += nbytes                       # actual raw bytes
             self.assertEqual(m, len(sc_encode(a)))
             self.round_trip(a)
 
     def test_random(self):
         for _ in range(10):
-            n = randint(0, 100000)
+            n = randrange(100000)
             endian = self.random_endian()
-            a = bitarray(n, endian)
-            a.setall(1)
+            a = ones(n, endian)
             for _ in range(16):
                 a &= urandom(n, endian)
                 self.round_trip(a)
 
     @skipIf(not DEBUG)
     def test_rts_empty(self):
-        a = bitarray()
-        self.assertEqual(_sc_rts(a), [0])
+        rts = _sc_rts(bitarray())
+        self.assertEqual(len(rts), 1)
+        self.assertEqual(rts, [0])
 
-    @skipIf(_SEGSIZE != 32)
+    @skipIf(not DEBUG or _SEGSIZE != 32)
     def test_rts_example(self):
         # see example before sc_calc_rts() in _util.c
         a = zeros(987)
@@ -1442,22 +1418,31 @@ class SC_Tests(unittest.TestCase, Util):
         self.assertEqual(len(rts), 5)
         self.assertEqual(rts, [0, 5, 5, 8, 12])
 
+    @skipIf(not DEBUG)
+    def test_rts_ones(self):
+        for _ in range(20):
+            n = randrange(10000)
+            a = ones(n)
+            rts = _sc_rts(a)
+            self.assertEqual(rts[0], 0)
+            self.assertEqual(rts[-1], n)
+            for i, v in enumerate(rts):
+                self.assertEqual(v, min(8 * _SEGSIZE * i, n))
+
     @skipIf(not DEBUG)
     def test_rts_random(self):
         segbits = 8 * _SEGSIZE
-        for n in range(2000):
+        for _ in range(20):
+            n = randrange(10000)
             a = urandom(n)
             rts = _sc_rts(a)
             self.assertEqual(len(rts), (n + segbits - 1) // segbits + 1)
             self.assertEqual(rts[0], 0)
             self.assertEqual(rts[-1], a.count())
-
             for i in range(len(rts) - 1):
                 seg_pop = a.count(1, segbits * i, segbits * (i + 1))
                 self.assertEqual(rts[i + 1] - rts[i], seg_pop)
 
-tests.append(SC_Tests)
-
 # ---------------------------------------------------------------------------
 
 class VLFTests(unittest.TestCase, Util):
@@ -1544,7 +1529,7 @@ class VLFTests(unittest.TestCase, Util):
         for bits in '', '0', '1', '', '11', '0000 1', '0011 01':
             self.assertEqual(vl_decode(stream), bitarray(bits))
 
-        arrays = [urandom(randint(0, 30)) for _ in range(1000)]
+        arrays = [urandom(randrange(30)) for _ in range(1000)]
         stream = iter(b''.join(vl_encode(a) for a in arrays))
         for a in arrays:
             self.assertEqual(vl_decode(stream), a)
@@ -1604,8 +1589,6 @@ class VLFTests(unittest.TestCase, Util):
         for a in self.randombitarrays():
             self.round_trip(a)
 
-tests.append(VLFTests)
-
 # ---------------------------------------------------------------------------
 
 class TestsIntegerization(unittest.TestCase, Util):
@@ -1774,16 +1757,16 @@ class TestsIntegerization(unittest.TestCase, Util):
                 self.assertEqual(i.bit_length(), len(a))
             # add a few trailing / leading zeros to bitarray
             if endian == 'big':
-                a = zeros(randint(0, 3), endian) + a
+                a = zeros(randrange(4), endian) + a
             else:
-                a = a + zeros(randint(0, 3), endian)
+                a = a + zeros(randrange(4), endian)
             self.assertEqual(a.endian(), endian)
             self.assertEqual(ba2int(a), i)
 
     def test_many(self):
         for i in range(20):
             self.check_round_trip(i)
-            self.check_round_trip(randint(0, 10 ** randint(3, 300)))
+            self.check_round_trip(randrange(10 ** randint(3, 300)))
 
     @staticmethod
     def twos_complement(i, num_bits):
@@ -1803,8 +1786,6 @@ class TestsIntegerization(unittest.TestCase, Util):
 
             self.assertEqual(i, self.twos_complement(j, len(a)))
 
-tests.append(TestsIntegerization)
-
 # ---------------------------------------------------------------------------
 
 class MixedTests(unittest.TestCase, Util):
@@ -1887,8 +1868,7 @@ class MixedTests(unittest.TestCase, Util):
                 self.assertEqual(ba2int(c), i << n)
 
     def test_primes(self):  # Sieve of Eratosthenes
-        sieve = bitarray(10000)
-        sieve.setall(1)
+        sieve = ones(10000)
         sieve[:2] = 0  # zero and one are not prime
         for i in range(2, 100):
             if sieve[i]:
@@ -1903,8 +1883,6 @@ class MixedTests(unittest.TestCase, Util):
         # the 1000th prime is 7919
         self.assertEqual(count_n(sieve, 1000) - 1, 7919)
 
-tests.append(MixedTests)
-
 # ---------------------------------------------------------------------------
 
 class TestsSerialization(unittest.TestCase, Util):
@@ -2003,8 +1981,6 @@ class TestsSerialization(unittest.TestCase, Util):
             self.assertEqual(a.endian(), c.endian())
             self.check_obj(c)
 
-tests.append(TestsSerialization)
-
 # ---------------------------------------------------------------------------
 
 class TestsHuffman(unittest.TestCase):
@@ -2087,7 +2063,7 @@ class TestsHuffman(unittest.TestCase):
         self.check_tree(code)
 
     def test_random_list(self):
-        plain = [randint(0, 100) for _ in range(500)]
+        plain = [randrange(100) for _ in range(500)]
         code = huffman_code(Counter(plain))
         a = bitarray()
         a.encode(code, plain)
@@ -2100,8 +2076,6 @@ class TestsHuffman(unittest.TestCase):
             code = huffman_code({i: random() for i in range(n)})
             self.check_tree(code)
 
-tests.append(TestsHuffman)
-
 # ---------------------------------------------------------------------------
 
 class TestsCanonicalHuffman(unittest.TestCase, Util):
@@ -2359,25 +2333,7 @@ class TestsCanonicalHuffman(unittest.TestCase, Util):
             freq = {i: random() for i in range(n)}
             self.check_code(*canonical_huffman(freq))
 
-
-tests.append(TestsCanonicalHuffman)
-
 # ---------------------------------------------------------------------------
 
-def run(verbosity=1):
-    import bitarray
-
-    print('bitarray.util is installed in: %s' % os.path.dirname(__file__))
-    print('bitarray version: %s' % bitarray.__version__)
-    print('Python version: %s' % sys.version)
-
-    suite = unittest.TestSuite()
-    for cls in tests:
-        suite.addTest(unittest.makeSuite(cls))
-
-    runner = unittest.TextTestRunner(verbosity=verbosity)
-    return runner.run(suite)
-
-
 if __name__ == '__main__':
-    run()
+    unittest.main()
