@@ -2,8 +2,8 @@ from bitarray import bitarray
 
 
 def show(a):
-    ptr, size, _endian, _unused, alloc = a.buffer_info()
-    print('%18d %10d %10d' % (ptr, size, alloc))
+    info = a.buffer_info()
+    print('%18d %10d %10d' % (info[0], info[1], info[4]))
 
 
 # make sure sequence of appends will always increase allocated size
@@ -27,12 +27,14 @@ for _ in range(100):
     prev = alloc
 
 
-# initalizing a bitarray from a string or list should not overallocate
-for n in 0, 4, 10, 100, 1000, 10_000:
-    a = bitarray(8 * n * '1')
-    assert n == a.buffer_info()[4]
+# initalizing a bitarray from a list or bitarray should not overallocate
+for n in range(1000):
+    alloc = (n + 3) & ~3
+    assert n <= alloc < n + 4 and alloc % 4 == 0
     a = bitarray(8 * n * [1])
-    assert n == a.buffer_info()[4]
+    assert alloc == a.buffer_info()[4]
+    b = bitarray(a)
+    assert alloc == b.buffer_info()[4]
 
 
 # starting from a large bitarray, make we sure we don't realloc each time
