@@ -4,7 +4,7 @@ from bitarray.util import int2ba, ba2int, pprint
 
 class SmallIntArray(object):
     """
-    A class which allows efficiently storeing an array of integers
+    Class which allows efficiently storing an array of integers
     represented by a specified number of bits.
     For example, an array with 1000 5 bit integers can be created,
     allowing each element in the array to take values form 0 to 31,
@@ -27,14 +27,14 @@ class SmallIntArray(object):
 
 
 if __name__ == '__main__':
-    from random import randint
+    from random import randrange
 
     # define array with 1000 integers, each represented by 5 bits
     a = SmallIntArray(1000, 5)
 
     b = [] # store values, for assertion below
     for i in range(1000):
-        v = randint(0, 31)
+        v = randrange(32)
         b.append(v)
         a[i] = v
 
